#! /usr/bin/env python
"""Print background filename

Print the filename of the current or previous background image.

This file is a part of XSetBg.

"""

__author__ = "Oleg Broytman <phd@phdru.name>"
__copyright__ = "Copyright (C) 2004-2015 PhiloSoft Design"
__license__ = "GNU GPL"


import sys
from xsetbg_db import xsetbg_db

if not xsetbg_db:
    sys.exit("Error: no database found")


def usage(code=0):
    sys.stderr.write("Usage: %s [-o|--old]\n" % sys.argv[0])
    sys.exit(code)


def get_args():
    from getopt import getopt, GetoptError

    try:
        options, arguments = getopt(sys.argv[1:], "he:o",
                                    ["help", "output-encoding=", "old"])
    except GetoptError:
        usage(1)

    old = False
    output_encoding = None

    for option, value in options:
        if option in ("-h", "--help"):
            usage()
        elif option in ("-e", "--output-encoding"):
            output_encoding = value
        elif option in ("-o", "--old"):
            old = True
        else:
            usage(2)

    if arguments:
        usage(3)

    if output_encoding is None:
        from m_lib.defenc import default_encoding
        output_encoding = default_encoding
    return old, output_encoding

old, output_encoding = get_args()


if old:
    index = 1
else:
    index = 0

filename = xsetbg_db.select('last_shown IS NOT NULL',
                            orderBy='-last_shown')[index].full_name

print filename.encode(output_encoding)
